@@ -4,6 +4,7 @@ from .handlers.HttpExceptionHandler import HttpExceptionHandler
 from .handlers.ModelNotFoundHandler import ModelNotFoundHandler
 from .DD import DD
 from .exceptions import (
+    AuthorizationException,
     InvalidRouteCompileException,
     RouteMiddlewareNotFound,
     ContainerError,
@@ -31,5 +32,7 @@ from .exceptions import (
     LoaderNotFound,
     QueueException,
     AmbiguousError,
+    MethodNotAllowedException,
     ModelNotFoundException,
+    ThrottleRequestsException,
 )
