@@ -4,6 +4,9 @@ from ...exceptions import InvalidToken
 class EncryptCookies:
     def before(self, request, response):
         for _, cookie in request.cookie_jar.all().items():
+            if not cookie.encrypt:
+                continue
+
             try:
                 cookie.value = request.app.make("sign").unsign(cookie.value)
             except InvalidToken:
@@ -13,6 +16,9 @@ class EncryptCookies:
 
     def after(self, request, response):
         for _, cookie in response.cookie_jar.all().items():
+            if not cookie.encrypt:
+                continue
+
             try:
                 cookie.value = request.app.make("sign").sign(cookie.value)
             except InvalidToken:
