@@ -2,6 +2,7 @@
 import shutil
 
 from ..utils.location import resources_path
+from ..utils.filesystem import make_full_directory
 from .Preset import Preset
 
 
@@ -27,6 +28,7 @@ class Bootstrap(Preset):
 
     def update_css(self):
         """Create/Override an app.scss file configured for the preset."""
+        make_full_directory(resources_path("css"))
         shutil.copyfile(
             self.get_template_path("_variables.scss"),
             resources_path("css/_variables.scss"),
