@@ -1,5 +1,5 @@
 from ..authentication import Auth
-from ..authentication.guards import WebGuard
+from ..authentication.guards import WebGuard, TestGuard
 from ..configuration import config
 from .Provider import Provider
 
@@ -11,7 +11,8 @@ class AuthenticationProvider(Provider):
     def register(self):
         auth = Auth(self.application).set_configuration(config("auth.guards"))
         auth.add_guard("web", WebGuard(self.application))
+        auth.add_guard("test", TestGuard(self.application))
         self.application.bind("auth", auth)
 
     def boot(self):
-        pass
+        self.application.make("auth").set_user(None)
