@@ -4,6 +4,7 @@ from markupsafe import Markup
 from ..providers import Provider
 from ..configuration import config
 from ..helpers import UrlsHelper, MixHelper, optional
+from ..facades import Dump
 
 
 class HelpersProvider(Provider):
@@ -17,7 +18,6 @@ class HelpersProvider(Provider):
 
     def boot(self):
         request = self.application.make("request")
-        urls_helper = self.application.make("url")
 
         self.application.make("view").share(
             {
@@ -31,14 +31,8 @@ class HelpersProvider(Provider):
                 "method": lambda method: (
                     Markup(f"<input type='hidden' name='__method' value='{method}' />")
                 ),
-                "asset": urls_helper.asset,
-                "url": urls_helper.url,
-                "mix": MixHelper(self.application).url,
-                "route": urls_helper.route,
-                "config": config,
+                "dd": Dump.dd,
                 "can": self.application.make("gate").allows,
                 "cannot": self.application.make("gate").denies,
-                "optional": optional,
-                "exists": self.application.make("view").exists,
             }
         )
