@@ -13,6 +13,16 @@ class Welcome(Mailable):
         )
 
 
+class Other(Mailable):
+    def build(self):
+        return (
+            self.to("idmann509@gmail.com")
+            .subject("Masonite 4")
+            .text("text from Masonite!")
+            .html("<h1>Hello from Masonite!</h1>")
+        )
+
+
 class TestSMTPDriver(TestCase):
     def setUp(self):
         super().setUp()
@@ -23,7 +33,6 @@ class TestSMTPDriver(TestCase):
         self.restore("mail")
 
     def test_mock_mail(self):
-        self.fake("mail")
         welcome_email = self.application.make("mail").mailable(Welcome()).send()
         (
             welcome_email.seeEmailCc("")
@@ -37,6 +46,9 @@ class TestSMTPDriver(TestCase):
         )
 
     def test_mock_mail_sending(self):
-        self.fake("mail")
         welcome_email = self.application.make("mail").mailable(Welcome())
         (welcome_email.seeEmailWasNotSent().send().seeEmailWasSent())
+
+    def test_mock_can_also_handle_options(self):
+        other_email = self.application.make("mail").mailable(Other())
+        other_email.send().seeEmailFrom("no-reply@masonite.com")
